# CapAppApi.UserApi

All URIs are relative to *https://endpoints-dot-capappw.appspot.com/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**getUser**](UserApi.md#getUser) | **GET** /user/me | User profile
[**loginUser**](UserApi.md#loginUser) | **POST** /user/login | Login a user and add the user if new.


<a name="getUser"></a>
# **getUser**
> User getUser()

User profile

The user profile endpoint returns information about the CapApp user that has authorized with the application.

### Example
```javascript
var CapAppApi = require('cap_app_api');
var defaultClient = CapAppApi.ApiClient.default;

// Configure OAuth2 access token for authorization: capapp_auth
var capapp_auth = defaultClient.authentications['capapp_auth'];
capapp_auth.accessToken = 'YOUR ACCESS TOKEN';

var apiInstance = new CapAppApi.UserApi();

var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.getUser(callback);
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**User**](User.md)

### Authorization

[capapp_auth](../README.md#capapp_auth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

<a name="loginUser"></a>
# **loginUser**
> User loginUser(name, opts)

Login a user and add the user if new.

Login a user and additionally add a new user if the user is new. Requires information obtained via a successful Facebook login. Refresh the Facebook user access token if the user already exists. The returned CapApp user access token will be used for authentication on other API calls.

### Example
```javascript
var CapAppApi = require('cap_app_api');
var defaultClient = CapAppApi.ApiClient.default;

// Configure OAuth2 access token for authorization: capapp_auth
var capapp_auth = defaultClient.authentications['capapp_auth'];
capapp_auth.accessToken = 'YOUR ACCESS TOKEN';

var apiInstance = new CapAppApi.UserApi();

var name = "name_example"; // String | The user name.

var opts = { 
  'tag': "tag_example" // String | An optional tag attached to any data created. Typically used for testing.
};

var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.loginUser(name, opts, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **name** | **String**| The user name. | 
 **tag** | **String**| An optional tag attached to any data created. Typically used for testing. | [optional] 

### Return type

[**User**](User.md)

### Authorization

[capapp_auth](../README.md#capapp_auth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

